"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureOnline = void 0;
// tslint:disable: no-use-before-declare
/**
 * 网络是否联接
 */
var isConnected = false;
/**
 * 是否隐藏在后台
 */
var isHidden = false;
var callbackPools = [];
function checkCallbacks() {
    if (isConnected && !isHidden) {
        while (callbackPools.length > 0) {
            callbackPools.shift()();
        }
    }
}
wx.onAppHide(function () { isHidden = true; });
wx.onAppShow(function () {
    isHidden = false;
    checkCallbacks();
});
wx.onNetworkStatusChange(function (res) {
    isConnected = res.isConnected;
    checkCallbacks();
});
wx.getNetworkType({
    success: function (res) {
        isConnected = res.networkType !== 'none';
        checkCallbacks();
    }
});
/**
 * 确保在线时执行
 * 网络掉线或者切换到后台的情况暂停发送
 * @param callback 回调
 * @param cancelToken 取消操作
 */
function ensureOnline(callback, cancelToken) {
    if (isConnected && !isHidden) {
        callback();
    }
    else {
        callbackPools.push(callback);
        if (cancelToken) {
            // tslint:disable-next-line: no-floating-promises
            cancelToken.promise.then(function () {
                var index = callbackPools.indexOf(callback);
                if (index !== -1) {
                    callbackPools.splice(index, 1);
                }
            });
        }
    }
}
exports.ensureOnline = ensureOnline;
//# sourceMappingURL=ensure-online.js.map